Install
=======

`HPGeom` requires the following python package and its dependencies:

* `numpy <https://github.com/numpy/numpy>`_

Building `HPGeom` also depends on a working C compiler.

To install from source, you can run from the root directory:

.. code-block:: python

  pip install --no-deps .
